#!/bin/sh
# -*-Scheme-*-
#
# Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015,
#     2016, 2017, 2018, 2019 Matthew Birkholz
#
# This file is part of a Gtk screen plugin for MIT/GNU Scheme Pucked.
#
# This plugin is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This plugin is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this plugin; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301, USA.

# Compile the gtk-screen option.

set -e
: ${MIT_SCHEME_EXE=mit-scheme}
${MIT_SCHEME_EXE} --batch-mode <<\EOF
(begin

  (parameterize ((param:suppress-loading-message? #t))
    (load-option 'cref)
    (load-option 'gtk)
    (load-option 'edwin))

  (if (name->package '(edwin screen gtk-screen))
      (error "The (edwin screen gtk-screen) package already exists."))
  (let ((package-set (package-set-pathname "gtk-screen")))
    (if (not (file-modification-time<? "gtk-screen.pkg" package-set))
	(cref/generate-trivial-constructor "gtk-screen"))
    (construct-packages-from-file (fasload package-set)))

  (let ((env (->environment '(edwin screen gtk-screen))))
    (compile-file "gtk-screen" '() env)
    (compile-file "gtk-faces"  '() env))

  (cref/generate-constructors "gtk-screen")
  )
EOF
suffix=`echo "(display (microcode-id/operating-system-suffix))" \
	| ${MIT_SCHEME_EXE} --batch-mode`
report=gtk-screen-$suffix.crf
if [ -s "$report" ]; then
    awk "{printf \"$report:%d: %s\\n\",NR,\$0}" $report
fi
